PAWpySeed: pawpyseed.core.wavefunction.Timer Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | Static Public Attributes | List of all members
pawpyseed.core.wavefunction.Timer Class Reference

## Static Public Member Functions
def | setup_time (t)
def | overlap_time (t)
def | augmentation_time (t)

## Static Public Attributes
int | ALL_SETUP_TIME = 0
int | ALL_OVERLAP_TIME = 0
int | ALL_AUGMENTATION_TIME = 0

## Member Function Documentation

def pawpyseed.core.wavefunction.Timer.augmentation_time | ( |  | t | ) |
| static

def pawpyseed.core.wavefunction.Timer.overlap_time | ( |  | t | ) |
| static

def pawpyseed.core.wavefunction.Timer.setup_time | ( |  | t | ) |
| static

## Member Data Documentation

int pawpyseed.core.wavefunction.Timer.ALL_AUGMENTATION_TIME = 0
| static

int pawpyseed.core.wavefunction.Timer.ALL_OVERLAP_TIME = 0
| static

int pawpyseed.core.wavefunction.Timer.ALL_SETUP_TIME = 0
| static

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/wavefunction.py